# eric7.Plugins.VcsPlugins.vcsMercurial.RebaseExtension.HgRebaseDialog

Module implementing a dialog to enter the data for a rebase session.

### Global Attributes

None

### Classes

HgRebaseDialog | Class implementing a dialog to enter the data for a rebase session.

### Functions

None

## HgRebaseDialog

Class implementing a dialog to enter the data for a rebase session.

### Derived from

QDialog, Ui_HgRebaseDialog

### Class Attributes

None

### Class Methods

None

### Methods

HgRebaseDialog | Constructor
__getRevision | Private method to generate the revision.
__updateOK | Private slot to update the OK button.
getData | Public method to retrieve the data for the rebase session.

### Static Methods

None

#### HgRebaseDialog (Constructor)

HgRebaseDialog(tagsList, branchesList, bookmarksList, version, parent=None)

Constructor

tagsList (list of str)
  list of tags
branchesList (list of str)
  list of branches
bookmarksList (list of str)
  list of bookmarks
version (tuple of int)
  tuple giving the Mercurial version
parent (QWidget)
  reference to the parent widget

#### HgRebaseDialog.__getRevision

__getRevision(no)

Private method to generate the revision.

no (int)
  revision number to generate (1 or 2)

Return:
  revision

Return Type:
  str

#### HgRebaseDialog.__updateOK

__updateOK()

Private slot to update the OK button.

#### HgRebaseDialog.getData

getData()

Public method to retrieve the data for the rebase session.

Return:
  tuple with a source indicator of "S" or "B", the source revision, the destination revision, a flag indicating to collapse, a flag indicating to keep the original changesets, a flag indicating to keep the original branch name, a flag indicating to detach the source, a flag indicating to perform a dry-run only and a flag indicating to perform a dry-run first, than ask for confirmation

Return Type:
  tuple of (str, str, str, bool, bool, bool, bool, bool, bool)

Up